@@ -1,6 +1,5 @@
 use parsercher;
 use parsercher::dom::Tag;
-use std::collections::HashMap;
 
 fn main() {
     let doc = r#"
@@ -13,9 +12,7 @@ fn main() {
 
     if let Ok(dom) = parsercher::parse(&doc) {
         let mut needle = Tag::new("li".to_string());
-        let mut attr = HashMap::new();
-        attr.insert("class".to_string(), "target".to_string());
-        needle.set_attr(attr);
+        needle.set_attr("class", "target");
         if let Some(texts) = parsercher::search_text_from_tag_children(&dom, &needle) {
             assert_eq!(texts.len(), 2);
             assert_eq!(texts[0], "first".to_string());
